<template>
  <div class="corporate-customers">
    <div class="full-page bg" v-show="componentName === 'table'">
      <div class="search-box">
        <SuperSearch :searchForm="queryParams" :basisOption="basisOption" @is-show-advance="advanced()"
                     @search="handleSearch" />
      </div>
      <div class="main-table-container">
        <div class="table-container" style="padding: 20px">
          <div style="margin-bottom: 10px" ref="btnPanel">
            <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="handleAdd">
              添加
            </el-button>
            <el-button slot="reference" icon="el-icon-delete" type="danger" plain class="btn btn-delete"
                       :disabled="this.currentDataDel.length === 0" @click="handleDelete()">
              删除
            </el-button>
          </div>
          <div class="table-content" ref="tabelRef">
            <el-table stripe v-loading="tableLoading" ref="multipleSelection" :data="tableData" :row-key="getRowKey"
                      :max-height="tableMaxHeight" class="table-list" border @selection-change="handleSelectionChange"
                      @row-dblclick="handleDbClick">
              <el-table-column type="selection" width="55" align="center"></el-table-column>
              <el-table-column type="index" width="60" label="序号" align="center">
              </el-table-column>
              <el-table-column prop="belongsOrgName" show-overflow-tooltip min-width="180" align="center"
                               label="所属公司">
              </el-table-column>
              <el-table-column prop="clientsName" show-overflow-tooltip min-width="120" align="center" label="客户名称">
              </el-table-column>
              <el-table-column prop="cardType" show-overflow-tooltip sortable min-width="120" align="center"
                               label="证件类型">
                <template v-slot="{ row }">
                  {{ getDictName('zjlx', row.cardType) }}
                </template>
              </el-table-column>
              <el-table-column prop="cardNo" show-overflow-tooltip min-width="120" align="center" label="证件编码"
                               sortable>
              </el-table-column>
              <el-table-column prop="bankName" show-overflow-tooltip min-width="120" align="center" label="开户银行">
              </el-table-column>
              <el-table-column prop="bankNo" show-overflow-tooltip min-width="120" align="center" label="银行账号">
              </el-table-column>
              <el-table-column prop="contactTel" show-overflow-tooltip min-width="120" align="center" label="联系电话">
              </el-table-column>
              <el-table-column prop="email" show-overflow-tooltip min-width="120" align="center" label="E-mail">
              </el-table-column>
              <el-table-column show-overflow-tooltip min-width="180" align="center" fixed="right" label="操作">
                <template v-slot="{ row }">
                  <el-link type="primary" :underline="false" style="margin-right: 10px;" @click="detailBtn(row)">
                    详情
                  </el-link>
                  <el-link type="danger" :underline="false" style="margin-right: 10px;" @click="handleDelete(row)">
                    删除
                  </el-link>
                  <el-link type="primary" :underline="false" style="margin-right: 10px;" @click="blacklistBtn(row)">
                    加入黑名单
                  </el-link>
                </template>
              </el-table-column>
            </el-table>
            <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParams"
                        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
          </div>
        </div>
      </div>
    </div>
    <!-- 弹层 -->
    <editAddDialog ref="editAddDialog" v-show="componentName === 'editAddDialog'" @closeComponent="closeComponent">
    </editAddDialog>
    <!-- 详情 -->
    <detailDialog v-show="componentName === 'detailDialog'" @closeComponent="closeComponent" ref="detailDialog">
    </detailDialog>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import utils from '@/utils.js'
import detailDialog from './components/detailDialog.vue'
import editAddDialog from './components/editAddDialog.vue'
import SuperSearch from '@/components/SuperSearch/index.vue'
import api from '@/api/assetsOperating/profilesCustomer/IndividualCustomers.js'
import pubSub from 'pubsub-js'

export default {
  name: 'IndividualCustomers',
  components: {
    SuperSearch,
    pagination,
    editAddDialog,
    detailDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      tableMaxHeight: '600px',
      loading: false,
      tableLoading: false,
      componentName: 'table',
      cardTypeData: [
        {
          name: '营业执照',
          value: 0
        },
        {
          name: '身份证',
          value: 1
        },
        {
          name: '驾驶证',
          value: 2
        },
        {
          name: '军官证',
          value: 3
        },
        {
          name: '护照',
          value: 4
        }
      ],
      tableData: [],
      multipleSelection: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        clientsType: 1,
        clientsStatus: 0,
        cardType: []
      },
      searchForm: {}, // 顶部搜索对象
      currentDataDel: [],
      sorter: [
        {
          direction: 'DESC',
          property: 'createTime'
        }
      ],
      basisOption: [
        {
          itemLabel: '证件类型',
          itemProp: 'cardType',
          itemType: 'checkbox',
          searchType: 'basic',
          labelWidth: '100px',
          option: []
        },
        {
          itemLabel: '客户名称',
          itemProp: 'clientsName',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        },
        {
          itemLabel: '证件编码',
          itemProp: 'cardNo',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        }
      ],
      pubSub: null
    }
  },

  created() {
    this.basisOption[0].option = utils.getDictItemsFromCache('zjlx')
    this.loadData()
  },
  mounted() {
    this.calcTableHeight()
    this.$root.$on('resize', () => {
      this.calcTableHeight(500)
    })

    // 添加自定义面包屑pub-sub
    this.pubSub = pubSub.subscribe('breadcrumb-click', (_, item) => {
      console.log(item)
      if (item.isCurrentRoute) this.componentName = 'table'
    })

  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      /*
       * 定义 escapeOpt 字段对应字典名 对象
       *  为重新加工结构赋值的新请求配置参数
       * */
      const querys = [
        {operation: 'LIKE', property: 'clientsType', relation: 'AND'},
        {operation: 'LIKE', property: 'clientsStatus', relation: 'AND'},
        {operation: 'IN', property: 'cardType', relation: 'AND'},
        {operation: 'LIKE', property: 'clientsName', relation: 'AND'},
        {operation: 'LIKE', property: 'cardNo', relation: 'AND'}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          const value = item[i.property]
          console.log(i)
          console.log(value)
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return {group: 'main', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  methods: {
    //关闭组件
    closeComponent(row) {
      this.componentName = 'table'
      this.loadData()
    },
    //证件类型翻译回显
    cardTypeName(value) {
      if (value != '') {
        return this.cardTypeData.filter(item => item.value == value)[0].name
      }
    },
    //字典翻译
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //获取数据
    loadData() {
      this.tableLoading = true
      api.queryData(this.computedQuery, res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParams.total = res.total
          this.tableLoading = false
        }
      })
    },
    //添加
    handleAdd() {
      this.componentName = 'editAddDialog'
      pubSub.publish('add-custom-breadcrumb', '添加')
      this.$refs.editAddDialog.addModifyBtn()
    },
    //详情
    detailBtn(row) {
      this.componentName = 'detailDialog'
      pubSub.publish('add-custom-breadcrumb', '详情')

      this.$refs.detailDialog.detail(row)
    },
    // 删除
    handleDelete(val) {
      let ids
      if (val) {
        ids = val.id
      } else {
        ids = this.currentDataDel.join()
      }
      this.$confirm('确定删除选中数据吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        api.deleteData(ids, res => {
          if (res.state) {
            this.$message.success('删除成功')
            this.loadData()
          }
        })
      })
    },
    //加入黑名单
    blacklistBtn(val) {
      this.$confirm('确定将此用户加入黑名单吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        api.getBlack(val.id, res => {
          if (res.state) {
            this.$message.success('加入成功')
            this.loadData()
          }
        })
      })
    },
    //修改
    handleDbClick(row) {
      this.componentName = 'editAddDialog'
      pubSub.publish('add-custom-breadcrumb', '编辑')
      this.$refs.editAddDialog.addModifyBtn(row)
    },
    // 顶部搜索
    handleSearch(data) {
      // data.cardType = data.cardType?data.cardType.join():''
      this.queryParams = data
      this.loadData()
    },
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    //表格选中
    handleSelectionChange(val) {
      this.currentDataDel = val.map((item) => {
        return item.id
      })
    },
    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.loadData()
    },
    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.loadData()
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    pubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped>
.search-box {
  //height: 350px;
  padding: 20px 30px;
  transition: all 1s;
  background-color: #ffffff;
  border-radius: 8px;
}

.table-content {
  width: 100%;
  height: calc(100% - 110px);

  .table-list {
    width: 100%;
    height: 100%;
  }
}

/deep/ .el-table .el-table__header th {
  padding: 12px 0 !important;
  background-color: #f1f5f8 !important;
}

/deep/ .el-table .el-table__header th .cell {
  font-size: 16px;
  color: #545454;
  font-weight: 700;
  font-family: PingFang SC-Medium, PingFang SC;
  white-space: nowrap;
}

.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.move-tree /deep/ .el-tree {
  height: 90%;
  overflow-y: auto;
  border: none;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(2) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }

  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}
</style>
